==> foundation-0.0.45.tgz: package/Data/DVEFDataSyncNode.js <==
//objects
import { ThreadComm } from "@divinestar/threads/";
import { WorldRegister } from "./World/WorldRegister.js";
import { DimensionsRegister } from "./World/DimensionsRegister.js";
import { RegionHeaderRegister, RegionHeaderTags, } from "./RegionHeaderRegister.js";
import { Column, Chunk, Region } from "./World/Classes/index.js";
import { DVEFDataSyncIds } from "./Constants/DVEFDataSyncIds.js";
import { RemoteDataSyncNode } from "@divinevoxel/core/Interfaces/Data/RemoteDataSyncNode.js";
export class DVEFDataSyncNode extends RemoteDataSyncNode {
    worldData = {
        dimension: ThreadComm.onDataSync(DVEFDataSyncIds.Dimesnion, (data) => {
            DimensionsRegister.registerDimension(data.id, data.options);
        }),
        chunk: ThreadComm.onDataSync(DVEFDataSyncIds.Chunk, (data) => {
            WorldRegister.chunk.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.chunk.remove(data);
        }),
        column: ThreadComm.onDataSync(DVEFDataSyncIds.Column, (data) => {
            WorldRegister.column.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.column.remove(data);
        }),
        region: ThreadComm.onDataSync(DVEFDataSyncIds.Region, (data) => {
            WorldRegister.region.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.region.remove(data);
        }),
        regionHeader: ThreadComm.onDataSync(DVEFDataSyncIds.RegionHeader, (data) => {
            RegionHeaderRegister.add(data[0], data[1]);
        }, (data) => {
            RegionHeaderRegister.remove(data);
        }),
    };
    worldDataTags = {
        chunk: ThreadComm.onDataSync(DVEFDataSyncIds.ChunkTags, (data) => {
            Chunk.Tags.$INIT(data);
        }),
        column: ThreadComm.onDataSync(DVEFDataSyncIds.ColumnTags, (data) => {
            Column.Tags.$INIT(data);
        }),
        region: ThreadComm.onDataSync(DVEFDataSyncIds.RegionTags, (data) => {
            Region.Tags.$INIT(data[0]);
            RegionHeaderTags.$INIT(data[1]);
        }),
    };
}

==> foundation-0.0.52.tgz: package/Data/DVEFDataSyncNode.js <==
//objects
import { ThreadComm } from "@divinestar/threads/";
import { WorldRegister } from "./World/WorldRegister.js";
import { DimensionsRegister } from "./World/DimensionsRegister.js";
import { RegionHeaderRegister, RegionHeaderTags, } from "./RegionHeaderRegister.js";
import { Column, Chunk, Region } from "./World/Classes/index.js";
import { DVEFDataSyncIds } from "./Constants/DVEFDataSyncIds.js";
import { RemoteDataSyncNode } from "@divinevoxel/core/Interfaces/Data/RemoteDataSyncNode.js";
export class DVEFDataSyncNode extends RemoteDataSyncNode {
    worldData = {
        dimension: ThreadComm.onDataSync(DVEFDataSyncIds.Dimesnion, (data) => {
            DimensionsRegister.instance.registerDimension(data.id, data.options);
        }),
        chunk: ThreadComm.onDataSync(DVEFDataSyncIds.Chunk, (data) => {
            WorldRegister.instance.chunk.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.instance.chunk.remove(data);
        }),
        column: ThreadComm.onDataSync(DVEFDataSyncIds.Column, (data) => {
            WorldRegister.instance.column.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.instance.column.remove(data);
        }),
        region: ThreadComm.onDataSync(DVEFDataSyncIds.Region, (data) => {
            WorldRegister.instance.region.add(data[0], data[1]);
        }, (data) => {
            WorldRegister.instance.region.remove(data);
        }),
        regionHeader: ThreadComm.onDataSync(DVEFDataSyncIds.RegionHeader, (data) => {
            RegionHeaderRegister.add(data[0], data[1]);
        }, (data) => {
            RegionHeaderRegister.remove(data);
        }),
    };
    worldDataTags = {
        chunk: ThreadComm.onDataSync(DVEFDataSyncIds.ChunkTags, (data) => {
            Chunk.Tags.$INIT(data);
        }),
        column: ThreadComm.onDataSync(DVEFDataSyncIds.ColumnTags, (data) => {
            Column.Tags.$INIT(data);
        }),
        region: ThreadComm.onDataSync(DVEFDataSyncIds.RegionTags, (data) => {
            Region.Tags.$INIT(data[0]);
            RegionHeaderTags.$INIT(data[1]);
        }),
    };
}
